[![Build Status](https://travis-ci.org/RobDWaller/gingerfy.svg?branch=master)](https://travis-ci.org/RobDWaller/gingerfy) [![codecov](https://codecov.io/gh/RobDWaller/gingerfy/branch/master/graph/badge.svg)](https://codecov.io/gh/RobDWaller/gingerfy) [![Maintainability](https://api.codeclimate.com/v1/badges/d43c3780ccf78820c5b7/maintainability)](https://codeclimate.com/github/RobDWaller/gingerfy/maintainability)
# Gingerfy

Remove unginger colours from strings and replace them with the one true colour, GINGER!!

```python
import gingerfy

result = gingerfy.fix("Blonde haired people are the best!")

print(result.get_fix())
```

> **Output:** Ginger haired people are the best!

## Notes

This project is obviously a joke, I come from a long line of Scottish and Irish gingers, so it's very much meant to be self-deprecating.

It was created to help me learn the basics of Python and how to pipeline Python code.

## Author

[RobDWaller](https://twitter.com/RobDWaller)
